@@ -46,7 +46,6 @@ OC.L10N.register(
     "Copy link" : "Kopioi linkki",
     "Move" : "Siirrä",
     "Add to folders" : "Lisää kansioihin",
-    "Delete" : "Poista",
     "Do you really want to delete this bookmark?" : "Haluatko varmasti poistaa tämän kirjanmerkin?",
     "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
     "Content pending" : "Odotetaan sisältöä",
@@ -103,8 +102,6 @@ OC.L10N.register(
     "Shared by {user}" : "Jakanut {user}",
     "Rename folder" : "Nimeä kansio uudelleen",
     "Move folder" : "Siirrä kansio",
-    "Delete folder" : "Poista kansio",
-    "Do you really want to delete this folder?" : "Haluatko varmasti poistaa tämän kansion?",
     "Choose folder" : "Valitse kansio",
     "Submit" : "Lähetä",
     "Cancel" : "Peruuta",
@@ -124,6 +121,7 @@ OC.L10N.register(
     "Broken links" : "Rikkinäisiä linkkejä",
     "New tag" : "Uusi tunniste",
     "Search tags" : "Etsi tunnisteita",
+    "Delete" : "Poista",
     "Untagged" : "Ilman tunnistetta",
     "{used} bookmarks of {available} available" : "{used}/{available} kirjanmerkkiä käytettävissä",
     "Settings" : "Asetukset",
@@ -152,6 +150,7 @@ OC.L10N.register(
     "Bookmarklet" : "Sovelluskirjanmerkki",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Vedä tämä selaimesi kirjanmerkkeihin ja paina kun haluat tehdä nettisivusta kirjanmerkin.",
     "Add to {instanceName}" : "Lisää kohteeseen {instanceName}",
+    "Need help?" : "Tarvitsetko apua?",
     "Archive path" : "Arkiston sijainti",
     "Backup path" : "Varmuuskopiokansio",
     "Please select \"Add to home screen\" in your browser menu" : "Valitse \"Lisää kotinäytölle\" selaimesi valikosta",
