@@ -32,7 +32,6 @@ OC.L10N.register(
     "Rename" : "שינוי שם",
     "Copy link" : "העתקת קישור",
     "Move" : "העברה",
-    "Delete" : "מחיקה",
     "Link copied to clipboard" : "הקישור הועתק ללוח הגזירים",
     "Open all selected" : "לפתוח את כל הנבחרים",
     "Move selection" : "העברת בחירה",
@@ -58,8 +57,6 @@ OC.L10N.register(
     "Enter folder title" : "נא למלא כותרת לתיקייה",
     "Shared by {user}" : "שותפה על ידי {user}",
     "Rename folder" : "שינוי שם תיקייה",
-    "Delete folder" : "מחיקת תיקייה",
-    "Do you really want to delete this folder?" : "למחוק את התיקייה הזאת?",
     "Choose folder" : "בחירת תיקייה",
     "Submit" : "שליחה",
     "Cancel" : "ביטול",
@@ -75,6 +72,7 @@ OC.L10N.register(
     "Shared with you" : "משותף אתך",
     "Files" : "קבצים",
     "Broken links" : "קישורים פגומים",
+    "Delete" : "מחיקה",
     "Untagged" : "ללא תגית",
     "{used} bookmarks of {available} available" : "{used} סימניות מתוך {available} זמינות",
     "Settings" : "הגדרות",
@@ -85,6 +83,7 @@ OC.L10N.register(
     "Install on home screen" : "התקנה על מסך הבית",
     "Bookmarklet" : "יישומון סימנייה",
     "Add to {instanceName}" : "הוספה אל {instanceName}",
+    "Need help?" : "עזרה נזקקת?",
     "Archive path" : "נתיב הארכיון",
     "Please select \"Add to home screen\" in your browser menu" : "נא לבחור באפשרות „הוספה למסך הבית” בתפריט הדפדפן שלך",
     "Title" : "תפקיד",
