@@ -45,7 +45,6 @@ OC.L10N.register(
     "Copy link" : "Kopiraj poveznicu",
     "Move" : "Premjesti",
     "Add to folders" : "Dodaj u mape",
-    "Delete" : "Izbriši",
     "Do you really want to delete this bookmark?" : "Želite li zaista izbrisati ovu knjižnu oznaku?",
     "Link copied to clipboard" : "Poveznica je kopirana u međuspremnik",
     "Content pending" : "Sadržaj na čekanju",
@@ -93,8 +92,6 @@ OC.L10N.register(
     "Shared by {user}" : "Dijeli {user}",
     "Rename folder" : "Preimenuj mapu",
     "Move folder" : "Premjesti mapu",
-    "Delete folder" : "Izbriši mapu",
-    "Do you really want to delete this folder?" : "Želite li zaista izbrisati ovu mapu?",
     "Choose folder" : "Odaberi mapu",
     "Submit" : "Šalji",
     "Cancel" : "Odustani",
@@ -113,6 +110,7 @@ OC.L10N.register(
     "Broken links" : "Prekinute poveznice",
     "New tag" : "Nova oznaka",
     "Search tags" : "Oznake pretraživanja",
+    "Delete" : "Izbriši",
     "Untagged" : "Uklonjene oznake",
     "{used} bookmarks of {available} available" : "{used} knjižnih oznaka od {available} dostupnih",
     "Settings" : "Postavke",
@@ -128,6 +126,7 @@ OC.L10N.register(
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Odvucite na knjižne oznake u svom pregledniku i kliknite kako biste brzo spremili mrežno mjesto u knjižne oznake.",
     "Add to {instanceName}" : "Dodaj u {instanceName}",
+    "Need help?" : "Treba li vam pomoć?",
     "Archive path" : "Put arhive",
     "Please select \"Add to home screen\" in your browser menu" : "Odaberite „Dodaj na početni zaslon“ u izborniku preglednika",
     "Title" : "Naslov",
