@@ -11,7 +11,6 @@ OC.L10N.register(
     "Rename" : "Ubah nama",
     "Copy link" : "Salin tautan",
     "Move" : "Pindah",
-    "Delete" : "Hapus",
     "Open all selected" : "Buka semua pilihan",
     "Move selection" : "Pindah pilihan",
     "Delete selection" : "Hapus pilihan",
@@ -30,7 +29,6 @@ OC.L10N.register(
     "Select folder" : "Pilih folder",
     "Shared by {user}" : "Dibagikan oleh {user}",
     "Rename folder" : "Ubah nama folder",
-    "Delete folder" : "Hapus folder",
     "Cancel" : "Membatalkan",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Memindahkan %n folder dan beberapa markah"],
     "_Moving %n folder_::_Moving %n folders_" : ["Memindahkan %n folder"],
@@ -38,10 +36,12 @@ OC.L10N.register(
     "Recent" : "Terbaru",
     "Shared with you" : "Shared with you",
     "Files" : "Berkas",
+    "Delete" : "Hapus",
     "Untagged" : "Belum ada tag",
     "Settings" : "Setelan",
     "No bookmarks here" : "Tidak ada markah di sini",
     "Client apps" : "Aplikasi klien",
+    "Need help?" : "Butuh bantuan?",
     "Title" : "Judul",
     "Link" : "Tautan",
     "Root folder" : "Folder akar",
