@@ -44,7 +44,6 @@ OC.L10N.register(
     "Rename" : "이름 바꾸기",
     "Copy link" : "링크 복사",
     "Move" : "이동",
-    "Delete" : "삭제",
     "Link copied to clipboard" : "링크가 클립보드로 복사됨",
     "Select all" : "Select all",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["선택된 %n 북마크들"],
@@ -63,17 +62,18 @@ OC.L10N.register(
     "Enter folder title" : "폴더명을 입력하시오.",
     "Shared by {user}" : "{user}가 공유한",
     "Rename folder" : "폴더 이름 바꾸기",
-    "Delete folder" : "폴더 삭제",
     "Choose folder" : "폴더 선택",
     "Submit" : "제출",
     "Cancel" : "취소",
     "Recent" : "최근 항목",
     "Shared with you" : "나와 공유됨",
     "Files" : "파일",
+    "Delete" : "삭제",
     "Untagged" : "태그 지우기",
     "Settings" : "설정",
     "Bookmarklet" : "북마크릿",
     "Add to {instanceName}" : "{instanceName}에 더하기",
+    "Need help?" : "도움이 필요한가요?",
     "Title" : "직위",
     "Link" : "링크",
     "Root folder" : "루트 폴더",
