@@ -44,7 +44,6 @@ OC.L10N.register(
     "Rename" : "Torra a numenare",
     "Copy link" : "Còpia ligòngiu",
     "Move" : "Tràmuda",
-    "Delete" : "Cantzella",
     "Do you really want to delete this bookmark?" : "A beru cheres cantzellare custu signalibru?",
     "Link copied to clipboard" : "Ligòngiu copiadu in punta de billete",
     "Content pending" : "Cuntenutu in suspesu",
@@ -90,8 +89,6 @@ OC.L10N.register(
     "Shared by {user}" : "Cumpartzidu dae {user}",
     "Rename folder" : "Torra a numenare sa cartella",
     "Move folder" : "Tràmuda sa cartella",
-    "Delete folder" : "Cantzella sa cartella",
-    "Do you really want to delete this folder?" : "A beru cheres cantzellare custa cartella?",
     "Choose folder" : "Sèbera sa cartella",
     "Submit" : "Imbia",
     "Cancel" : "Annulla",
@@ -109,6 +106,7 @@ OC.L10N.register(
     "Broken links" : "Ligòngios segados",
     "New tag" : "Eticheta noa",
     "Search tags" : "Chirca etichetas",
+    "Delete" : "Cantzella",
     "Untagged" : "Sena eticheta",
     "{used} bookmarks of {available} available" : "{used} signalibros de {available} a disponimentu",
     "Settings" : "Cunfiguratzione",
@@ -122,6 +120,7 @@ OC.L10N.register(
     "Install on home screen" : "Installa in s'ischermada printzipale",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName}" : "Agiunghe a {instanceName}",
+    "Need help?" : "Boles agiudu?",
     "Archive path" : "Caminu archìviu",
     "Please select \"Add to home screen\" in your browser menu" : "Pro praghere, seletziona \"Agiunghe a s'ischermada printzipale\" in su menu de su navigadore tuo",
     "Title" : "Tìtulu",
