@@ -46,7 +46,6 @@ OC.L10N.register(
     "Copy link" : "复制链接",
     "Move" : "移动",
     "Add to folders" : "添加到文件夹",
-    "Delete" : "删除",
     "Do you really want to delete this bookmark?" : "你真想删除这个书签吗？",
     "Link copied to clipboard" : "链接已复制到剪贴板",
     "Content pending" : "内容待定",
@@ -102,8 +101,6 @@ OC.L10N.register(
     "Shared by {user}" : "由{user} 共享",
     "Rename folder" : "重命名文件夹",
     "Move folder" : "移动文件夹",
-    "Delete folder" : "删除文件夹",
-    "Do you really want to delete this folder?" : "您真想删除这个文件夹吗？",
     "Choose folder" : "选择文件夹",
     "Submit" : "提交",
     "Cancel" : "取消",
@@ -123,6 +120,7 @@ OC.L10N.register(
     "Broken links" : "失效的链接",
     "New tag" : "新标签",
     "Search tags" : "搜索标签",
+    "Delete" : "删除",
     "Untagged" : "未标记的",
     "{used} bookmarks of {available} available" : " {available}书签可用，已用{used}",
     "Settings" : "设置",
@@ -143,6 +141,7 @@ OC.L10N.register(
     "Bookmarklet" : "小书签",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "将此拖到浏览器书签中，并单击它可快速将网页添加为书签。",
     "Add to {instanceName}" : "添加到 {instanceName}",
+    "Need help?" : "需要帮助？",
     "Archive path" : "归档路径",
     "Backup path" : "备份路径",
     "Please select \"Add to home screen\" in your browser menu" : "请点击浏览器菜单中的“添加到主屏幕”",
