@@ -11,10 +11,15 @@ namespace OCA\Bookmarks;
 use OC;
 use OCP\AppFramework\Http\TemplateResponse;
 
+/**
+ * @psalm-template S of int
+ * @psalm-template H of array<string, mixed>
+ * @psalm-implements TemplateResponse<S,H>
+ */
 class AugmentedTemplateResponse extends TemplateResponse {
 	public function render() {
 		$return = parent::render();
-		$return = preg_replace('/<link rel="manifest" href="(.*?)">/i', '<link rel="manifest" href="'. OC::$server->getURLGenerator()->linkToRouteAbsolute('bookmarks.web_view.manifest').'">', $return);
+		preg_replace('/<link rel="manifest" href="(.*?)">/i', '<link rel="manifest" href="'. OC::$server->getURLGenerator()->linkToRouteAbsolute('bookmarks.web_view.manifest').'">', $return);
 		return $return;
 	}
 }
